@@ -170,7 +170,7 @@ impl<T: Serialize + DeserializeOwned + std::fmt::Debug> Store<T> {
 			.append(false)
 			.open(path.as_ref())
 			.await?;
-		Ok(Self{
+		let mut store = Self{
 			path: path.as_ref().to_path_buf(),
 			file: BufStream::new(fd),
 			header: Header{
@@ -181,7 +181,9 @@ impl<T: Serialize + DeserializeOwned + std::fmt::Debug> Store<T> {
 			},
 			index_cache: HashMap::with_hasher(fnv::FnvBuildHasher::default()),
 			_nothing: std::marker::PhantomData
-		})
+		};
+		store.header = store.get_header().await?;
+		Ok(store)
 	} // }}}
 
 	fn index_start_position(&self) -> u64 /* {{{ */ {
@@ -264,10 +266,9 @@ impl<T: Serialize + DeserializeOwned + std::fmt::Debug> Store<T> {
 	/// means making sure the format is fully up-to-date and writing completed.
 	#[inline]
 	pub async fn is_valid(&mut self) -> Result<bool, Error> /* {{{ */ {
-		let header = self.get_header().await?;
 		Ok(
-			header.format_version == CURRENT_FORMAT_VERSION &&
-			header.completed_writing
+			self.header.format_version == CURRENT_FORMAT_VERSION &&
+			self.header.completed_writing
 		)
 	} // }}}
 
@@ -299,7 +300,6 @@ impl<T: Serialize + DeserializeOwned + std::fmt::Debug> Store<T> {
 		let position = match self.index_cache.get(&key) {
 			Some(v) => *v,
 			None => {
-				self.header = self.get_header().await?;
 				let index = match self.find_index_entry(key).await? {
 					Some(v) => v,
 					None => return Err(Error::NotFound(key))
